flutter_quill_to_pdf library

Classes

CheckboxDecorator
This class determines how will look the leading appearance
Converter<Doc, Type>
Converter is a parent that's provides the essential rules for generate and create a document pdf file for that project
ConverterConfigurator<D, T>
Use this class if you want to create your own PDF configurator implementation instead Converter
CustomWidget
CustomWidget is used to match lines with a formatting and
DeltaAttributesOptions
Contains all custom properties that we want in our delta Use this with together delta processor to add properties more easily without format all delta
DocumentOptions
These are the general configuration for the pdf document and general view mode and orientation
FontFamilyRequest
FontFamilyResponse
PdfConfigurator<T, D>
PDFConverter
PDFPageFormat
PDFPageFormat is a default implementation to decide all the properties for the pdf document width, height and margins
PdfService
A Manager that contains all operations for PDF services

Enums

ListTypeWidget
This is an enum that decides how will be builded the List block

Properties

darkThemeInCodeBlock Map<String, TextStyle>
final
lightThemeInCodeblock Map<String, TextStyle>
final

Typedefs

PageBuilder = Page Function(List<Widget>, ThemeData theme, PdfPageFormat pageFormat)
PDFLeadingWidget<W> = W Function(String type, int indentLevel, Object? extraArgs)
PDFWidgetBuilder<T, W> = W Function(T data, Map<String, dynamic>? blockAttributes, [Object? extraArgs])
PDFWidgetErrorBuilder<T, W, R> = W Function(T data, R alternativeData, [Object? extraArgs])