StringExtension extension

on

Properties

isTotallyEmpty bool

Available on String, provided by the StringExtension extension

no setter

Methods

equals(String other, {bool caseSensitive = true, Pattern? pattern, bool useThisInstead = false}) bool

Available on String, provided by the StringExtension extension

Equals is a similar function that use Java or Kotlin classes to see the equality from two objects
fixCommonErrorInsertsInRawDelta() String

Available on String, provided by the StringExtension extension